@@ -70,24 +70,12 @@ cell2bool(lex_ctxt* lexic, tree_cell* c)
       if (c->size == 0)
 	return 0;
       if(c->x.str_val[0] == '0' && c->size == 1)
-	{
-	  /* 
-	   * This gives the same semantics as Perl ("0" is false), 
-	   * but I do not agree with it. 
-	   * This piece of code is here from the begining of NASL2; it 
-	   * probably fixed some compatibility issue with old 
-	   * quick & dirty scripts. 
-	   * I added this warning to check if we can switch to a
-	   * simpler behaviour (empty string = false, not empty = true)
-	   */
-	  nasl_perror(lexic, "cell2boll: string '0' is FALSE\n");
 	  return 0;
-	}
      return 1;
 
     case REF_ARRAY:
     case DYN_ARRAY:
-      /*nasl_perror(lexic, "cell2bool: converting array to boolean does not make sense!\n");*/
+      nasl_perror(lexic, "cell2bool: converting array to boolean does not make sense!\n");
       return 1;
 
     default:
@@ -1325,7 +1313,7 @@ nasl_exec(lex_ctxt* lexic, tree_cell* st)
 	{
 	case CONST_INT:
 	  x = tc1->x.i_val;
-	  y = cell2int(lexic, tc2);
+	  y = cell2int(lexic, st->link[1]);
 	  ret = int2cell(x + y);
 	  break;
 
@@ -1450,7 +1438,7 @@ nasl_exec(lex_ctxt* lexic, tree_cell* st)
 	    }
 
 	  if (len2 == 0 || len1 < len2 || 
-	      (p = (char*)nasl_memmem(p1, len1,  p2, len2)) == NULL)
+	      (p = (char*)memmem(p1, len1,  p2, len2)) == NULL)
 	    {
 	      s3 = emalloc(len1);
 	      memcpy(s3, p1, len1);
@@ -1628,7 +1616,7 @@ nasl_exec(lex_ctxt* lexic, tree_cell* st)
 	}
 
       if(len1 <= len2)		
-      	flag = ((void*)nasl_memmem(p2, len2, p1, len1) != NULL);
+      	flag = ((void*)memmem(p2, len2, p1, len1) != NULL);
       else
       	flag = 0;
 	
@@ -1831,7 +1819,7 @@ execute_nasl_script(struct arglist * script_infos, const char* name, const char
 
      tc.type = CONST_DATA;
      p = strrchr(name, '/');
-     if (p == NULL) p = (char*)name; else p ++;
+     if (p == NULL) p = name; else p ++;
      tc.x.str_val = p;
      tc.size = strlen(p);
      add_named_var_to_ctxt(lexic, "SCRIPT_NAME", &tc);
@@ -1868,7 +1856,9 @@ execute_nasl_script(struct arglist * script_infos, const char* name, const char
 #endif
 
  chdir(old_dir);
+#if 1
  if ( mode & NASL_EXEC_DONT_CLEANUP ) return err;
+#endif
 
  nasl_clean_ctx(&ctx);
  free_lex_ctxt(lexic);
