@@ -161,14 +161,8 @@ nasl_pread(lex_ctxt * lexic)
     {
       sz = 0; str = emalloc(1);
 
-      errno = 0;
-      while ((n = fread(buf, 1, sizeof(buf), fp)) > 0 || errno == EINTR ) /* && kill(pid, 0) >= 0)*/
+      while ((n = fread(buf, 1, sizeof(buf), fp)) > 0) /* && kill(pid, 0) >= 0)*/
 	{
-          if ( errno == EINTR ) 
-          {
-           errno = 0;
-	   continue;
-	  }
 	  sz2 = sz + n;
 	  str2 = erealloc(str, sz2);
 	  if (str2 == NULL)
@@ -180,7 +174,7 @@ nasl_pread(lex_ctxt * lexic)
 	  memcpy(str + sz, buf, n);
 	  sz = sz2;
 	}
-      if (ferror(fp) && errno != EINTR )
+      if (ferror(fp))
 	nasl_perror(lexic, "nasl_pread: fread(): %s\n", strerror(errno));
 
       (void) nessus_pclose(fp, pid);
@@ -295,7 +289,6 @@ nasl_fread(lex_ctxt * lexic)
   retc = alloc_typed_cell(CONST_DATA);
   retc->size = len;
   retc->x.str_val = buf;
-  fclose(fp);
   return retc;
   
  error:
@@ -354,9 +347,9 @@ nasl_fwrite(lex_ctxt * lexic)
       nasl_perror(lexic, "fwrite: need two arguments 'data' and 'file'\n");
       return NULL;
     }
-  len = get_var_size_by_name(lexic, "data");
+  len = get_var_size_by_name(lexic, "name");
   
-  fp = fopen(fname, "w");
+  fp = fopen(content, "w");
   if (fp == NULL)
     {
       nasl_perror(lexic, "fwrite: %s: %s\n", fname, strerror(errno));
@@ -393,250 +386,37 @@ tree_cell*
 nasl_get_tmp_dir(lex_ctxt * lexic)
 {
   tree_cell	*retc;
-  char		path[MAXPATHLEN];
+  char		*p, path[MAXPATHLEN];
+  int		warn = 0;
 
  if (check_authenticated(lexic) < 0) return NULL;
+ retc = alloc_typed_cell(CONST_DATA);
  snprintf(path, sizeof(path), "%s/nessus/tmp/", NESSUS_STATE_DIR);
  if (access(path, R_OK|W_OK|X_OK) < 0)
-     {
-     nasl_perror(lexic, "get_tmp_dir(): %s not available - check your Nessus installation\n", path);
-     return NULL;
-     }
+   {
+     warn ++;
+     perror(path);
+     p = getenv("TMPDIR");
+     if (p != NULL)
+       {
+	 snprintf(path, sizeof(path), "%s/", p);
+	 if (access(path, R_OK|W_OK|X_OK) < 0)
+	   {
+	     perror(path);
+	     p = NULL;
+	   }
+       }
+     if (p == NULL)
+       snprintf(path, sizeof(path), "/tmp/");
+     /* Here we could create a "safe" directory - is this really necessary? */
+   }
+ if (warn)
+   fprintf(stderr, "get_tmp_dir: using \"%s\" temporary directory (may be unsafe)\n", path);
      
- retc = alloc_typed_cell(CONST_DATA);
  retc->x.str_val = strdup(path);
  retc->size = strlen(retc->x.str_val);
  return retc;
 }
 
 
-/*
- *  File access functions : Dangerous
- */
-
-
-tree_cell*
-nasl_file_stat(lex_ctxt * lexic)
-{
-  tree_cell	*retc;
-  char		*fname;
-  struct stat	st;
-
-  if ( check_authenticated(lexic) < 0 ) return NULL;
- 
-  fname = get_str_var_by_num(lexic, 0);
-  if (fname == NULL)
-    {
-      nasl_perror(lexic, "file_stat: need one argument (file name)\n");
-      return NULL;
-    }
-  
-  if (stat(fname, &st) < 0)
-      return NULL;
-
-  retc = alloc_typed_cell(CONST_INT);
-  retc->x.i_val = (int)st.st_size;
-  return retc;
-}
-
-
-tree_cell*
-nasl_file_open(lex_ctxt * lexic)
-{
-  tree_cell	*retc;
-  char		*fname, *mode;
-  int		fd; 
-  int		imode;
-
-  if ( check_authenticated(lexic) < 0 ) return NULL;
- 
-  fname = get_str_local_var_by_name(lexic, "name");
-  if (fname == NULL)
-    {
-      nasl_perror(lexic, "file_open: need file name argument\n");
-      return NULL;
-    }
- 
-  mode = get_str_local_var_by_name(lexic, "mode");
-  if (mode == NULL)
-    {
-      nasl_perror(lexic, "file_open: need file mode argument\n");
-      return NULL;
-    }
-
-  if ( strcmp(mode, "r") == 0 ) 
-	imode = O_RDONLY;
-  else if ( strcmp(mode, "w") == 0 )
-	imode = O_WRONLY|O_CREAT;
-  else if ( strcmp(mode, "w+") == 0 )
-	imode = O_WRONLY|O_TRUNC|O_CREAT;
-   else if ( strcmp(mode, "a") == 0 )
-	imode = O_WRONLY|O_APPEND|O_CREAT;
-   else if ( strcmp(mode, "a+") == 0 )
-	imode = O_RDWR|O_APPEND|O_CREAT;
-
-  fd = open(fname, imode, 0600);
-  if ( fd < 0 )
-    {
-      nasl_perror(lexic, "file_open: %s: %s\n", fname, strerror(errno));
-      return NULL;
-    }
-
-  retc = alloc_typed_cell(CONST_INT);
-  retc->x.i_val = fd;
-  return retc;
-}
-
-
-tree_cell*
-nasl_file_close(lex_ctxt * lexic)
-{
-  tree_cell	*retc;
-  int		fd;
-
-  if ( check_authenticated(lexic) < 0 ) return NULL;
- 
-  fd = get_int_var_by_num(lexic, 0, -1);
-  if ( fd < 0 )
-    {
-      nasl_perror(lexic, "file_close: need file pointer argument\n");
-      return NULL;
-    }
- 
-  if (close(fd) < 0)
-    {
-      nasl_perror(lexic, "file_close: %s\n", strerror(errno));
-      return NULL;
-    }
-
-  retc = alloc_typed_cell(CONST_INT);
-  retc->x.i_val = 0;
-  return retc;
-}
-
-
-
-tree_cell*
-nasl_file_read(lex_ctxt * lexic)
-{
-  tree_cell	*retc;
-  char		*buf;
-  int		fd;
-  int           flength;
-  int           n;
-
-  if ( check_authenticated(lexic) < 0 ) return NULL;
-
-
- 
-  fd = get_int_local_var_by_name(lexic, "fp", -1);
-  if (fd < 0 )
-    {
-      nasl_perror(lexic, "file_read: need file pointer argument\n");
-      return NULL;
-    }
- 
-  flength = get_int_local_var_by_name(lexic, "length", 0);
-
-  buf = emalloc(flength + 1);
-  if (buf == NULL)
-    {
-      nasl_perror(lexic, "file_read: cannot malloc %d bytes\n", flength);
-      goto error;
-    }
-
-  for ( n = 0 ; n < flength ; )
-  { 
-   int e;
-   errno = 0;
-   e  = read(fd, buf + n, flength - n);
-   if ( e < 0 && errno == EINTR ) continue;
-   else if ( e <= 0 ) break;
-   else n += e;
-  }
-  
-  retc = alloc_typed_cell(CONST_DATA);
-  retc->size = n;
-  retc->x.str_val = buf;
-  return retc;
- error:
-  efree(&buf);
-  return NULL;
-}
-
-
-
-tree_cell*
-nasl_file_write(lex_ctxt * lexic)
-{
-  tree_cell	*retc;
-  char		*content;
-  int		len;
-  int		fd;
-  int 		n;
-
-  if ( check_authenticated(lexic) < 0 ) return NULL;
-
-  content = get_str_local_var_by_name(lexic, "data");
-  fd = get_int_local_var_by_name(lexic, "fp", -1);
-  if (content == NULL || fd < 0 )
-    {
-      nasl_perror(lexic, "file_write: need two arguments 'fp' and 'data'\n");
-      return NULL;
-    }
-  len = get_var_size_by_name(lexic, "data");
- 
-
-  for ( n = 0 ; n < len ;  )
-  { 
-   int e;
-   errno = 0;
-   e = write(fd, content + n ,len - n);
-   if ( e < 0 && errno == EINTR ) continue;
-   else if ( e <= 0 ) 
-     {
-      nasl_perror(lexic, "file_write: write() failed - %s\n", strerror(errno));
-      break;
-     }
-   else n += e ;
-  }
-   
-
-
-  retc = alloc_typed_cell(CONST_INT);
-  retc->x.i_val = n;
-  return retc;
-}
-
-
-tree_cell*
-nasl_file_seek(lex_ctxt * lexic)
-{
-  tree_cell	*retc;
-  int		fd;
-  int           foffset;
-
-  if ( check_authenticated(lexic) < 0 ) return NULL;
-
-
-
-
-  foffset = get_int_local_var_by_name(lexic, "offset", 0);
-  fd = get_int_local_var_by_name(lexic, "fp", -1);
-  if (fd < 0 )
-    {
-      nasl_perror(lexic, "file_seek: need one arguments 'fp'\n");
-      return NULL;
-    }
-
-  if ( lseek(fd, foffset, SEEK_SET) < 0 )
-    {
-      nasl_perror(lexic, "fseek: %s\n", strerror(errno));
-      return NULL;
-    }
-
-  retc = alloc_typed_cell(CONST_INT);
-  retc->x.i_val = 0;
-  return retc;
-}
 
