@@ -66,9 +66,11 @@ get_func(lex_ctxt* ctxt, const char* name, int h)
   return NULL;
 }
 
-static int qstrcmp(const void * a, const void * b)
+static int
+stringcompare(const void * a,  const void * b)
 {
- return strcmp(a,b);
+  char ** s1 = (char**)a, ** s2 = (char**)b;
+  return strcmp(*s1, *s2);
 }
 
 nasl_func*
@@ -101,8 +103,7 @@ insert_nasl_func(lex_ctxt* lexic, const char* fname, tree_cell* decl_node)
 	if (pc->x.str_val != NULL)
 	  pf->args_names[i ++] = estrdup(pc->x.str_val);
       /* sort arg names */
-      qsort(pf->args_names, pf->nb_named_args, 
-	    sizeof(pf->args_names[0]), qstrcmp);
+      qsort(pf->args_names, pf->nb_named_args, sizeof(pf->args_names[0]), stringcompare);
 
       pf->block = decl_node->link[1];
       ref_cell(pf->block);
@@ -144,13 +145,6 @@ get_func_ref_by_name(lex_ctxt* ctxt, const char* name)
     return NULL;
 }
 
-static int
-stringcompare(const void * a,  const void * b)
-{
-  char ** s1 = (char**)a, ** s2 = (char**)b;
-  return strcmp(*s1, *s2);
-}
-
 extern FILE*	nasl_trace_fp;
 
 tree_cell*
@@ -193,7 +187,11 @@ nasl_func_call(lex_ctxt* lexic, const nasl_func* f, tree_cell* arg_list)
 	else
 	  {
 	    size_t num = f->nb_named_args;
-	    if (lfind(&pc->x.str_val, f->args_names, &num, sizeof(char*), stringcompare) != NULL)
+	    if (lfind(&pc->x.str_val, f->args_names, &num,
+		      sizeof(char*), stringcompare) == NULL)
+	      nasl_perror(lexic, "No such arg '%s' for function '%s' - might be ignored\n",
+		      pc->x.str_val, f->func_name);
+	    else
 	      nb_n ++;
 	  }
   
