@@ -511,13 +511,13 @@ script_get_preference_file_location(lex_ctxt* lexic)
   value = get_plugin_preference(script_infos, pref);
   if(value == NULL)
     {
-      nasl_perror(lexic, "script_get_preference_file_location: could not get preference %s\n", pref);
+      nasl_perror(lexic, "script_get_preference_file_location: could not get preference '%s'\n", pref);
       return NULL;
     }
   local = get_plugin_preference_fname(script_infos, value);
   if(local == NULL)
     {
-      nasl_perror(lexic, "script_get_preference_file_location: could not get local file name from preference %s\n", pref);
+      nasl_perror(lexic, "script_get_preference_file_location: could not get local file name from preference '%s' (value=%s)\n", pref, value);
       return NULL;
     }
 
@@ -600,7 +600,7 @@ tree_cell * get_kb_list(lex_ctxt * lexic)
   else if(res->type == KB_TYPE_STR)
   {
    v.var_type = VAR2_DATA;
-   v.v.v_str.s_val = (unsigned char*)res->v.v_str;
+   v.v.v_str.s_val = res->v.v_str;
    v.v.v_str.s_siz = strlen(res->v.v_str);
    add_var_to_array(a, res->name, &v);
    num_elems ++;
@@ -741,13 +741,6 @@ tree_cell * replace_kb_item(lex_ctxt * lexic)
   nasl_perror(lexic, "Syntax error with replace_kb_item() [null name]\n", name);
   return FAKE_CELL;
  }
-
- if (! lexic->authenticated && 
-     strncmp(name, SECRET_KB_PREFIX, sizeof(SECRET_KB_PREFIX) - 1) == 0)
- {
-  nasl_perror(lexic, "Only signed scripts can set a Secret/ KB entry\n");
-  return FAKE_CELL;
- }
  
  if(type == VAR2_INT)
  {
@@ -780,14 +773,6 @@ tree_cell * set_kb_item(lex_ctxt * lexic)
   return FAKE_CELL;
  }
  
- if (! lexic->authenticated && 
-     strncmp(name, SECRET_KB_PREFIX, sizeof(SECRET_KB_PREFIX) - 1) == 0)
- {
-  nasl_perror(lexic, "Only signed scripts can set a Secret/ KB entry\n");
-  return FAKE_CELL;
- }
-
-
  if(type == VAR2_INT)
  {
   int value = get_int_local_var_by_name(lexic, "value", -1);
@@ -1010,6 +995,7 @@ tree_cell * nasl_shared_socket_register( lex_ctxt * lexic )
   char * name = get_str_local_var_by_name(lexic, "name");
   int    soc  = get_int_local_var_by_name(lexic, "socket", -1);
   struct arglist * script_infos = lexic->script_infos;
+  int type, opt_len = sizeof(type);
 
  if ( name == NULL || soc < 0 )
  { 
@@ -1052,6 +1038,7 @@ tree_cell * nasl_shared_socket_acquire( lex_ctxt * lexic )
 tree_cell * nasl_shared_socket_release( lex_ctxt * lexic )
 {
   char * name = get_str_var_by_num(lexic, 0);
+  int fd;
   struct arglist * script_infos = lexic->script_infos;
 
  if ( name == NULL )
@@ -1070,6 +1057,7 @@ tree_cell * nasl_shared_socket_release( lex_ctxt * lexic )
 tree_cell * nasl_shared_socket_destroy( lex_ctxt * lexic )
 {
   char * name = get_str_var_by_num(lexic, 0);
+  int fd;
   struct arglist * script_infos = lexic->script_infos;
 
  if ( name == NULL )
