@@ -30,7 +30,6 @@
   
 /*--------------------------------------------------------------------------*/
 #include <includes.h>
-#include "nasl.h"
 
 #include "nasl_tree.h"
 #include "nasl_global_ctxt.h"
@@ -162,8 +161,7 @@ static tree_cell * nasl_open_privileged_socket(lex_ctxt * lexic, int proto)
  tree_cell * retc;
  struct timeval tv;
  fd_set rd;
- int opt;
- unsigned int opt_sz;
+ int opt, opt_sz;
  
  
  
@@ -195,7 +193,7 @@ restart:
 	 return NULL;
 
 tryagain :
- if ( current_sport < 128 && sport < 0 ) return NULL;
+ if ( current_sport < 128 ) return NULL;
  e =  set_socket_source_addr(sock, sport > 0 ? sport : current_sport--);
  
  /*
@@ -233,11 +231,6 @@ tryagain :
      else  
           return NULL;
    }
-   else if ( errno != EINPROGRESS )
-   { 
-     close(sock);
-     return NULL;
-   }
  }
 
   do {
@@ -248,12 +241,6 @@ tryagain :
   e = select(sock + 1, NULL, &rd, NULL, to > 0 ? &tv:NULL);
   } while ( e < 0 && errno == EINTR );
 
- if ( e <= 0 ) 
- {
-   close ( sock );
-   return FAKE_CELL;
- }
-
  block_socket(sock);
  opt_sz = sizeof(opt);
 
@@ -322,8 +309,11 @@ tree_cell * nasl_open_sock_tcp_bufsz(lex_ctxt * lexic, int bufsz)
    bufsz = get_int_local_var_by_name(lexic, "bufsz", 0);
   
  port = get_int_var_by_num(lexic, 0, -1);
- if(port < 0)
-	 return NULL;
+ if (port < 0 || port > 65535)
+   {
+     nasl_perror(lexic, "open_sock_tcp: missing or invalid port\n");
+     return NULL;
+   }
  
  if(transport < 0)
    soc =  open_stream_auto_encaps(script_infos, port, to);
@@ -367,7 +357,6 @@ tree_cell * nasl_open_sock_udp(lex_ctxt * lexic)
 	 return NULL;
    
  ia = plug_get_host_ip(script_infos);
- if ( ia == NULL ) return NULL;
  bzero(&soca, sizeof(soca));
  soca.sin_addr.s_addr = ia->s_addr;
  soca.sin_port = htons(port);
@@ -398,8 +387,7 @@ tree_cell * nasl_recv(lex_ctxt * lexic)
  struct timeval tv;
  int new_len = 0;
  tree_cell * retc;
- int type = -1;
- unsigned int opt_len = sizeof(type);
+ int type = -1, opt_len = sizeof(type);
  int e;
  
 
@@ -565,11 +553,9 @@ tree_cell * nasl_send(lex_ctxt * lexic)
  char * data = get_str_local_var_by_name(lexic, "data");
  int option = get_int_local_var_by_name(lexic, "option", 0);
  int length = get_int_local_var_by_name(lexic, "length", 0);
- int data_length = get_var_size_by_name(lexic, "data");
  int n;
  tree_cell * retc;
- int type;
- unsigned int type_len = sizeof(type);
+ int type, type_len = sizeof(type);
 
  
  if(soc <= 0 || data == NULL)
@@ -579,8 +565,8 @@ tree_cell * nasl_send(lex_ctxt * lexic)
 	return NULL;
  }
 
- if( length <= 0 || length > data_length )
-	length = data_length;
+ if( length == 0 )
+	length = get_var_size_by_name(lexic, "data");
  
  
  if(!fd_is_stream(soc) && 
@@ -608,7 +594,7 @@ tree_cell * nasl_close_socket(lex_ctxt * lexic)
 {
  int soc;
  int type;
- unsigned int opt_len = sizeof(type);
+ int opt_len = sizeof(type);
  int e;
  
  soc = get_int_var_by_num(lexic, 0, -1);
@@ -753,11 +739,8 @@ tree_cell*
 nasl_get_source_port(lex_ctxt* lexic)
 {
   struct sockaddr_in	ia;
-  int		s, fd;
-  unsigned  int	l;
+  int		i, s, fd, l;
   tree_cell	*retc;
-  int         type;
-  unsigned int type_len = sizeof(type);
 
   s = get_int_var_by_num(lexic, 0, -1);
   if (s < 0)
@@ -765,12 +748,7 @@ nasl_get_source_port(lex_ctxt* lexic)
       nasl_perror(lexic, "get_source_port: missing socket parameter\n");
       return NULL;
     }
-  if(!fd_is_stream(s) && getsockopt(s, SOL_SOCKET, SO_TYPE, &type, &type_len) == 0 && type == SOCK_DGRAM)
-       fd = s;
-   else
-       fd = nessus_get_socket_from_connection(s);
- 
-
+  fd = nessus_get_socket_from_connection(s);
   if (fd < 0)
     {
       nasl_perror(lexic, "get_source_port: invalid socket parameter %d\n", s);
@@ -786,50 +764,3 @@ nasl_get_source_port(lex_ctxt* lexic)
   retc->x.i_val = ntohs(ia.sin_port);
   return retc;  
 }
-
-
-
-tree_cell*
-nasl_socket_get_error(lex_ctxt* lexic)
-{
-  int soc = get_int_var_by_num(lexic, 0, -1);
-  tree_cell * retc;
-  int err;
-
-  if ( soc < 0 || ! fd_is_stream(soc) )
-	return NULL;
-
-  err = stream_get_err(soc);
-  retc = alloc_typed_cell(CONST_INT);
-  
-  switch ( err )
-  {
-    case 0 :
-	retc->x.i_val = NASL_ERR_NOERR;
-	break;
-    case ETIMEDOUT:
-	retc->x.i_val = NASL_ERR_ETIMEDOUT;
-	break;
-    case EBADF:
-    case EPIPE:
-#ifdef ECONNRESET
-    case ECONNRESET:
-#endif
-#ifdef ENOTSOCK
-    case ENOTSOCK:
-#endif
-	 retc->x.i_val = NASL_ERR_ECONNRESET;
-         break;
-
-    case ENETUNREACH:
-    case EHOSTUNREACH:
-	 retc->x.i_val = NASL_ERR_EUNREACH;
-         break;
-
-default:
-	fprintf(stderr, "Unknown error %d %s\n", err, strerror(err));
-  }
-
-
- return retc;
-}
