@@ -141,8 +141,13 @@ get_var_ref_by_name(lex_ctxt* ctxt, const char* name, int climb)
 		    c->ctx_vars.hash_elt[h] = v;
 		  }
 #endif
-	      return v;
-    }
+#if NASL_DEBUG > 0
+		if (c != ctxt /* Not the original context */ 
+		    && c->up_ctxt != NULL) /*  Not the global context */
+		  nasl_perror(ctxt, "get_var_ref_by_name: variable %s found in intermediate context. This might be misleading\n", name);
+#endif
+		return v;
+	      }
 #ifdef SILLY_OPT
 	    else
 	      prev = v;
@@ -302,9 +307,7 @@ get_array_elem(lex_ctxt* ctxt, const char* name, tree_cell* idx)
       switch(idx->type)
 	{
 	case CONST_INT:
-	  av = nasl_get_var_by_num(&u->v.v_arr, idx->x.i_val, 
-				   /* avoid dangling pointers */
-				   strcmp(name, "_FCT_ANON_ARGS"));
+	  av = nasl_get_var_by_num(&u->v.v_arr, idx->x.i_val, 1);
 	  return var2cell(av);
 	  
 	case CONST_STR:
@@ -516,9 +519,7 @@ copy_anon_var(anon_nasl_var* v1, const anon_nasl_var *v2)
       break;
 
     case VAR2_ARRAY:
-      copy_array(&v1->v.v_arr, &v2->v.v_arr, 1);
-      break;
-
+      /* TBD: handle arrays here for multi-dimensional arrays */
     default:
       nasl_perror(NULL, "copy_anon_var: unhandled type 0x%x\n", v2->var_type);
       clear_anon_var(v1);
@@ -625,9 +626,6 @@ affect_to_anon_var(anon_nasl_var* v1, tree_cell* rval)
   void		*p;
 
 
-  if ( v1 == NULL || v1 == FAKE_CELL )
-	return NULL;
-
   t1 = v1->var_type;
 
   if (rval == NULL || rval == FAKE_CELL)
@@ -654,13 +652,6 @@ affect_to_anon_var(anon_nasl_var* v1, tree_cell* rval)
 
     case REF_VAR:
       v2 = rval->x.ref_val;
-      if ( v2 == NULL )
-	{
-	  t2 = 0;
-	  a = NULL;
-	  break;
-	}
-
       if (v2 == v1)
 	{
 #if NASL_DEBUG > 1
@@ -668,7 +659,6 @@ affect_to_anon_var(anon_nasl_var* v1, tree_cell* rval)
 #endif
 	  return FAKE_CELL;
 	}
-
       t2 = v2->var_type;
       if (t2 == VAR2_ARRAY)
 	a = &v2->v.v_arr;	/* ? */
@@ -974,9 +964,7 @@ nasl_read_var_ref(lex_ctxt* lexic, tree_cell* tc)
   v = tc->x.ref_val;
   if (v == NULL)
     {
-#if NASL_DEBUG > 0
       nasl_perror(lexic, "nasl_read_var_ref: NULL variable in REF_VAR\n");
-#endif
       return NULL;
     }
 
@@ -995,7 +983,7 @@ nasl_read_var_ref(lex_ctxt* lexic, tree_cell* tc)
       /* Fix bad string length */
       if (v->v.v_str.s_siz <= 0 && v->v.v_str.s_val[0] != '\0')
 	{
-	  v->v.v_str.s_siz = strlen((char*)v->v.v_str.s_val);
+	  v->v.v_str.s_siz = strlen(v->v.v_str.s_val);
 	  nasl_perror(lexic, "nasl_read_var_ref: Bad string length fixed\n");
 	}
       /* Go on next case */
@@ -1068,7 +1056,7 @@ nasl_incr_variable(lex_ctxt* lexic, tree_cell* tc, int pre, int val)
 #if NASL_DEBUG > 0
       nasl_perror(lexic, "nasl_incr_variable: variable %s is a STRING %s - converting to integer\n", "", get_line_nb(tc));
 #endif
-      old_val = v->v.v_str.s_val == NULL ? 0 : atoi((char*)v->v.v_str.s_val);
+      old_val = v->v.v_str.s_val == NULL ? 0 : atoi(v->v.v_str.s_val);
       break;
     case VAR2_UNDEF:
 #if NASL_DEBUG > 0
@@ -1110,7 +1098,7 @@ var2int(anon_nasl_var* v, int defval)
 
     case VAR2_STRING:
     case VAR2_DATA:
-      return atoi((char*)v->v.v_str.s_val);
+      return atoi(v->v.v_str.s_val);
 
     case VAR2_UNDEF:
 #if NASL_DEBUG > 1
@@ -1573,7 +1561,7 @@ make_array_from_elems(tree_cell* el)
 	      else
 		{
 		  v.v.v_str.s_siz = c2->size;
-		  v.v.v_str.s_val = (unsigned char*)c2->x.str_val;
+		  v.v.v_str.s_val = c2->x.str_val;
 		}
 	      break;
 	    default:
